| get_mdd_list | R Documentation |
Function to return mammal species list avaliable by version
get_mdd_list(version = "v1_2")
version |
The taxonomy version |
A data.frame object with mammal species by version
Expert range maps of global mammal distributions harmonized to three taxonomic authorities \Sexpr[results=rd]{tools:::Rd_expr_doi("doi:10.5281/zenodo.10806734")}
get_mdd_list(version = "test")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.