| mddSpList_v1_3 | R Documentation |
A list of species related with shapefiles in MDD. Includes taxonomy
mddSpList_v1_3
mddSpListA data frame with 6513 rows and 8 columns:
Order of the species
Family of the species
Genus of the species
Species Name
Species binomial name
...
Expert range maps of global mammal distributions harmonised to three taxonomic authorities. \Sexpr[results=rd]{tools:::Rd_expr_doi("doi:10.5281/zenodo.10806734")}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.